import sys
from pysam import VariantFile

vcf = VariantFile(sys.argv[1])
n = 0

for v in vcf:
    if len(v.alts) > 1: continue
    if v.qual < 20: continue
    gts = [s['GT'] for s in v.samples.values()]
    an = sum(len(gt) for gt in gts)
    ac = sum(sum(gt) for gt in gts)
    aaf = (float(ac) / float(an))
    if aaf > 0.05: continue
    n += 1
print(n)



import sys
from vcf import Reader
import gzip

vcf = Reader(open(sys.argv[1], 'rb'))
n = 0

for v in vcf:
    if len(v.ALT) > 1: continue
    if v.QUAL < 20: continue
    if v.aaf[0] > 0.05: continue
    n += 1
print(n)



from tabulate import tabulate
from collections import OrderedDict
vals = """
#bcftools
986798

real    3m49.024s
user    3m48.620s
sys 0m7.848s
#cyvcf2
984214

real    4m5.190s
user    4m5.048s
sys 0m0.112s
#pysam
984214

real    33m12.417s
user    33m11.920s
sys 0m0.244s
""".split("#")
vals = [x.strip() for x in vals if x.strip()]

key = 'time (seconds)'

def parse_group(g):
    lines = g.split("\n")
    d = OrderedDict([
            ('name', lines[0].strip()),
            ('time', next(x for x in lines if x.startswith('user')).split()[1].rstrip('s'))
            ])
    minutes = float(d['time'].split('m')[0])
    seconds = float(d['time'].split('m')[1])
    d[key] = 60 * minutes + seconds
    del d['time']
    return d



tbl = [parse_group(g) for g in vals]
base = next(d for d in tbl if d['name'] == 'cyvcf2')[key]
for d in tbl:
    d['ratio'] = "%.2f" % (d[key] / base)
    d[key] = "%.1f" % d[key]

print(r"\begin{table}[h]")
print(r"\caption{Timing VCF filtering}")
print(tabulate(tbl, headers="keys", tablefmt="latex"))
print(r"\end{table}")



import numpy as np
import sys
from scipy.stats import binom_test
path = sys.argv[1]

import cyvcf2
vcf = cyvcf2.VCF(path)
PRO, MOM, DAD = range(3)

for v in vcf:
    if v.QUAL < 10: continue
    if np.any(v.gt_depths < 10): continue
    refs, alts = v.gt_ref_depths, v.gt_alt_depths
    if not all(v.gt_types == [vcf.HET, vcf.HOM_REF, vcf.HOM_REF]): continue
    if alts[MOM] > 1 or alts[DAD] > 1: continue
    print("%s\t%d\t%s\t%s\t%s" % (v.CHROM, v.start, v.REF,
        ",".join(v.ALT), ",".join(v.gt_bases)))
